@@ -8,6 +8,6 @@ test_that("earlyreg gives a slope and intercept of an amplification curve data f
 
   expect_that(res, is_a("numeric"))
   expect_length(res, 3)
-  expect_that(round(res[1], 2) == 119.96, is_true())
-  expect_that(round(res[2], 4) == -25.8153, is_true())
+  expect_true(round(res[1], 2) == 119.96)
+  expect_true(round(res[2], 4) == -25.8153)
 })
